@@ -108,6 +108,11 @@ class StatusCode:
 
     # B01开头的状态码
     TIMEOUT = ("B0100", "系统执行超时")
+    TASK_PENDING = ("B0101", "任务等待中")
+    TASK_RUNNING = ("B0102", "任务运行中")
+    TASK_SUCCESS = ("B0103", "任务成功")
+    TASK_FAIL = ("B0104", "任务失败")
+    TASK_NOT_EXIST = ("B0105", "任务不存在")
     # B02开头的状态码
     STRIKE_RECOVERY = ("B0200", "系统容灾系统被触发")
     # B03开头的状态码
